@@ -10,7 +10,7 @@ use vars qw(
   $Doctype_decl  $Content_decl
 );
 @ISA = ('Pod::Simple::PullParser');
-$VERSION = '3.11';
+$VERSION = '3.12';
 
 use UNIVERSAL ();
 BEGIN {
@@ -70,6 +70,8 @@ __PACKAGE__->_accessorize(
  'title_prefix',  'title_postfix',
   # What to put before and after the title in the head.
   # Should already be &-escaped
+
+ 'html_h_level',
   
  'html_header_before_title',
  'html_header_after_title',
@@ -208,9 +210,25 @@ sub new {
   $new->html_footer( qq[\n<!-- end doc -->\n\n</body></html>\n] );
 
   $new->{'Tagmap'} = {%Tagmap};
+
   return $new;
 }
 
+sub __adjust_html_h_levels {
+  my ($self) = @_;
+  my $Tagmap = $self->{'Tagmap'};
+
+  my $add = $self->html_h_level;
+  return unless defined $add;
+  return if ($self->{'Adjusted_html_h_levels'}||0) == $add;
+
+  $add -= 1;
+  for (1 .. 4) {
+    $Tagmap->{"head$_"}  =~ s/$_/$_ + $add/e;
+    $Tagmap->{"/head$_"} =~ s/$_/$_ + $add/e;
+  }
+}
+
 sub batch_mode_page_object_init {
   my($self, $batchconvobj, $module, $infile, $outfile, $depth) = @_;
   DEBUG and print "Initting $self\n  for $module\n",
@@ -433,6 +451,8 @@ sub _do_middle_main_loop {
   my $self = $_[0];
   my $fh = $self->{'output_fh'};
   my $tagmap = $self->{'Tagmap'};
+
+  $self->__adjust_html_h_levels;
   
   my($token, $type, $tagname, $linkto, $linktype);
   my @stack;
@@ -922,7 +942,7 @@ Patches against Pod::Simple are welcome. Please send bug reports to
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002-2004 Sean M. Burke.  All rights reserved.
+Copyright (c) 2002-2004 Sean M. Burke.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -931,6 +951,14 @@ This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to L<Hurricane Electrict|http://he.net/> for permission to use its
+L<Linux man pages online|http://man.he.net/> site for man page links.
+
+Thanks to L<search.cpan.org|http://search.cpan.org/> for permission to use the
+site for Perl module links.
+
 =head1 AUTHOR
 
 Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
