@@ -1,12 +1,11 @@
+
+require 5;
 package Pod::Simple::Methody;
-
-require 5.006;
 use strict;
-use warnings;
 use Pod::Simple ();
-
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
+use vars qw(@ISA $VERSION);
+$VERSION = '3.12';
+@ISA = ('Pod::Simple');
 
 # Yes, we could use named variables, but I want this to be impose
 # as little an additional performance hit as possible.
@@ -33,7 +32,7 @@ sub _handle_element_end {
   ( $_[0]->can( 'end_' . $_[1] )
     || return
   )->(
-    $_[0], $_[2]
+    $_[0]
   );
 }
 
@@ -52,12 +51,12 @@ Pod::Simple::Methody -- turn Pod::Simple events into method calls
  use strict;
  package SomePodFormatter;
  use base qw(Pod::Simple::Methody);
-
+ 
  sub handle_text {
    my($self, $text) = @_;
    ...
  }
-
+ 
  sub start_head1 {
    my($self, $attrs) = @_;
    ...
@@ -66,7 +65,7 @@ Pod::Simple::Methody -- turn Pod::Simple events into method calls
    my($self) = @_;
    ...
  }
-
+ 
 ...and start_/end_ methods for whatever other events you want to catch.
 
 =head1 DESCRIPTION
@@ -116,8 +115,8 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
